﻿using System.Net;
using System.Net.Mail;

namespace TestProject1
{
    /// <summary>
    /// Class that pretends to create a new user account. The result of the pretend
    /// account creation sends an email to the specified account as if a real account
    /// had been created.
    /// 
    /// This class is for demo purposes only; when driving a real app, the code in this
    /// class would perform an actual account creation in the app.
    /// </summary>
    public class AccountCreationPageObject
    {
        public void CreateNewAccount(MailinatorConfig creds, string emailAddress)
        {
            // For a real app, we'd fill out the required GUI fields or
            // send the appropriate API messages to cause the app to send the
            // account activation email.
            //
            // For demo purposes, we'll just simulate that here
            var smtpClient = new SmtpClient(creds.SmtpServerAddress)
            {
                Port = 587,
                Credentials = new NetworkCredential(creds.SendingEmailAddress, creds.AppId),
                EnableSsl = true,
                DeliveryMethod = SmtpDeliveryMethod.Network
            };

            smtpClient.Send(creds.SendingEmailAddress, emailAddress, "Activation Email", "This is the fake activation email!!!");
        }
    }
}
